levelModule = {
	mt = {},

	New = function()
		local newObj = {}
		setmetatable( newObj, levelModule.mt) --binds metaTable to table
		for k,v in pairs(levelModule) do --loops through table (even with named indexes)
			newObj[k] = v -- matches a key in the vec table to a value
			--vec.k = v is the same thing
		end
		newObj.levelID = -1
		newObj.startingProxy = ""
		newObj.physicalProxy = "" --This links to the game object in the main game object
		newObj.levelName = "New function not overrided"
		
		newObj.startingAreaID = -1
		newObj.startingAreaPlayerPos = vmath.vector3()
		newObj.currentArea = ""

		--Triggers
		newObj.triggerSaves = {}
		return  newObj
	end,

	-------------
	--Save/load--
	-------------

	addToSaveObjects = function(self, id, message)
		if self.triggerSaves[id] == nil then
			self.triggerSaves[id] = {}
		end
		self.triggerSaves[id][message.ID] = message
		print("Saved")
	end,

	getSavedObjects = function(self, id)
		return self.triggerSaves[id]
	end,

	getSaveObjectData = function(self, level_id, object_ID)
		return self.triggerSaves[level_id][object_ID]
	end,

	save = function(self)
		local saveTable = {}
		-- Save info
		saveTable.worldSafeInfo = {}

		--Save the info
		saveTable.worldName = self:get_save_name()
		saveTable.worldSafeInfo = self.triggerSaves
		return saveTable
	end,

	load = function(self, loadTable)
		-- Trigger saves
		self.triggerSaves = loadTable.worldSafeInfo
	end,

	-----------------
	-- Battle Info --
	-----------------

	getBattleBackgroundFactory = function(self, ID)
		error("Must overload in level module")
		-- return url for a factory
	end,

	getEnemyTypeFromArea = function(self, ID)
		error("Must overload in level module")
	end,

	----------------
	--Area Loading--
	----------------

	setCurrentArea = function(self, area)
		self.currentArea = area
	end,

	getCurrentArea = function(self)
		return self.currentArea
	end,

	getAreaFactoryByID = function(self, ID)
		error("Override in level class")
	end,

	getStartPlayerPos = function(self)
		return self.startingAreaPlayerPos
	end,

	getStartingAreaID = function(self)
		return self.startingAreaID
	end,

	-----------------
	-- Level Proxy --
	-----------------

	get_save_name = function(self)
		return "World_" .. self.startingProxy
	end,
	
	get_physical_proxy = function(self)
		return self.physicalProxy
	end,

	get_starting_proxy = function(self)
		return self.startingProxy
	end,
	
	get_levelID = function(self)
		return self.levelID
	end,

	get_levelName = function(self)
		return self.levelName
	end
}